@@ -17,7 +17,7 @@
 #  endif
 #endif
 
-#define VERSION "1.6.6"
+#define VERSION "1.6.7"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -224,6 +224,7 @@ extern int print_ps_pic(char *filename);
 extern int export_fw(char *filename);
 extern int export_mdl_mol(FILE *fp);
 extern int export_emf(char *filename);
+extern int export_sxd(char *filename);
 extern int readrc(void);
 extern int writerc(void);
 extern void pdbrotate(int,int,int);
@@ -243,7 +244,7 @@ extern int undo_set_memory_limit(size_t memmax);
 GdkPixmap *picture,*savedpicture,*preview;
 GtkWidget *textbox;
 int xcent,ycent;
-int bondtypes=20;
+int bondtypes=22;
 int *tmpx,*tmpy;
 char formula[51],weight[21],eweight[21],compos[65];
   
@@ -291,6 +292,7 @@ void setup_printer(GtkWidget*,gpointer);
 void do_complete(void);
 void check_fig2dev(void);
 extern void check_babel(void);
+extern void check_fig2sxd(void);
 void ct_crash(int);
 void restore_picture(void);
 void getpreview(GtkWidget*, gint, gint,  GdkEventButton*, gpointer);
@@ -319,6 +321,8 @@ int gridy=0;
 int serif_flag=0;
 int refx=0,refy=0,refmark=0;
 double bondlen_mm=10.668;
+int db_dist=4;
+int mb_dist=10;
 int epsoption, use_whiteout;
 int bgred,bggreen,bgblue;
 char bghexcolor[10];
@@ -328,3 +332,4 @@ extern int undo_malloc(size_t);
 int atnum;
 int draw_ok=0;
 int sdfindex=0;
+int have_fig2sxd;
