@@ -17,7 +17,7 @@
 #  endif
 #endif
 
-#define VERSION "1.6.6"
+#define VERSION "1.6.7"
 #define PIXMAPWIDTH 1600
 #define PIXMAPHEIGHT 1200
 
@@ -240,9 +240,11 @@ extern void xfig_circle (FILE*, int, int, int, int);
 extern void xfig_spline (FILE *, int , int , int , int , int , int , int , int , int, int);
 extern int exfig(FILE*, int);
 extern int export_fw(char*);
+extern int export_sxd(char*);
 extern int readrc(void);
 extern int writerc(void);
 extern void check_fig2dev(void);
+extern void check_fig2sxd(void);
 
 #ifdef LIBUNDO
 extern void undo_free(void*);
@@ -283,6 +285,8 @@ extern int gridx,gridy;
 extern int serif_flag;
 extern int refx,refy,refmark;
 extern double bondlen_mm;
+extern int db_dist;
+extern int mb_dist;
 extern int epsoption, use_whiteout;
 extern int bgred,bggreen,bgblue;
 extern char bghexcolor[10];
@@ -290,4 +294,5 @@ extern int curfontsize;
 extern int atnum;
 extern int draw_ok;
 extern int sdfindex;
+extern int have_fig2sxd;
 /*@end@*/
