@@ -159,7 +159,7 @@ Display_Mol ()
 	  break;
 	case 1:
 	  {			/*leftdouble */
-	    coord = multi_bonds (hpc->x, hpc->y, hpc->tx, hpc->ty, 10);
+	    coord = multi_bonds (hpc->x, hpc->y, hpc->tx, hpc->ty, mb_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
@@ -168,7 +168,7 @@ Display_Mol ()
 	  break;
 	case 2:
 	  {			/*rightdouble */
-	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, 10);
+	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, mb_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
@@ -213,7 +213,7 @@ Display_Mol ()
 	  break;
 	case 4:
 	  {			/*middouble */
-	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, 4);
+	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, db_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
@@ -223,12 +223,12 @@ Display_Mol ()
 	  break;
 	case 3:
 	  {			/*triple */
-	    coord = multi_bonds (hpc->x, hpc->y, hpc->tx, hpc->ty, 10);
+	    coord = multi_bonds (hpc->x, hpc->y, hpc->tx, hpc->ty, mb_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
-	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, 10);
+	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, mb_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
@@ -237,7 +237,7 @@ Display_Mol ()
 	  break;
 	case 14:
 	  {			/*left partial double */
-	    coord = multi_bonds (hpc->x, hpc->y, hpc->tx, hpc->ty, 10);
+	    coord = multi_bonds (hpc->x, hpc->y, hpc->tx, hpc->ty, mb_dist);
 	    DrawDashed (coord->x, coord->y, coord->tx, coord->ty,
 			hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
@@ -246,7 +246,7 @@ Display_Mol ()
 	  break;
 	case 15:
 	  {			/*right partial double */
-	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, 10);
+	    coord = multi_bonds (hpc->tx, hpc->ty, hpc->x, hpc->y, mb_dist);
 	    DrawDashed (coord->x, coord->y, coord->tx, coord->ty,
 			hpc->smarked + hpc->tmarked,hpc->color);
 	    Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty,
@@ -260,7 +260,7 @@ Display_Mol ()
 	case 18:
 	  {			/*triple, equal lengths */
 	  Drawline (hpc->x, hpc->y, hpc->tx, hpc->ty, hpc->smarked + hpc->tmarked,hpc->color);	/*single */
-	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, 5);
+	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, db_dist);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
@@ -270,7 +270,7 @@ Display_Mol ()
 	  break;
 	case 19:
 	  {			/*quadruple */
-	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, 5);
+	    coord = center_double_bond (hpc->x, hpc->y, hpc->tx, hpc->ty, db_dist+1);
 	    tmpx1=coord->x;
 	    tmpy1=coord->y;
             tmptx1=coord->tx;
@@ -280,13 +280,13 @@ Display_Mol ()
 	    tmpy2=coord->y;
             tmptx2=coord->tx;
             tmpty2=coord->ty;
-	    coord = center_double_bond (tmpx1, tmpy1, tmptx1, tmpty1, 3);
+	    coord = center_double_bond (tmpx1, tmpy1, tmptx1, tmpty1, db_dist-1);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
-	    coord = center_double_bond (tmpx2, tmpy2,tmptx2, tmpty2, 3);
+	    coord = center_double_bond (tmpx2, tmpy2,tmptx2, tmpty2, db_dist-1);
 	    Drawline (coord->x, coord->y, coord->tx, coord->ty,
 		      hpc->smarked + hpc->tmarked,hpc->color);
 	    coord++;
@@ -353,14 +353,14 @@ draw_preview_bonds (x, y, tx, ty, b)
       break;
     case 1:
       {				/*leftdouble */
-	coord = multi_bonds (x, y, tx, ty, 10);
+	coord = multi_bonds (x, y, tx, ty, mb_dist);
 	Drawline (coord->x, coord->y, coord->tx, coord->ty, 0,0);
 	Drawline (x, y, tx, ty, 0, 0);
       }
       break;
     case 2:
       {				/*rightdouble */
-	coord = multi_bonds (tx, ty, x, y, 10);
+	coord = multi_bonds (tx, ty, x, y, mb_dist);
 	Drawline (coord->x, coord->y, coord->tx, coord->ty, 0,0);
 	Drawline (x, y, tx, ty, 0,0);
       }
@@ -394,7 +394,7 @@ draw_preview_bonds (x, y, tx, ty, b)
       break;
     case 4:
       {				/*middouble */
-	coord = center_double_bond (x, y, tx, ty, 4);
+	coord = center_double_bond (x, y, tx, ty, db_dist);
 	Drawline (coord->x, coord->y, coord->tx, coord->ty, 0, 0);
 	coord++;
 	Drawline (coord->x, coord->y, coord->tx, coord->ty, 0, 0);
@@ -402,24 +402,24 @@ draw_preview_bonds (x, y, tx, ty, b)
       break;
     case 3:
       {				/*triple */
-	coord = multi_bonds (x, y, tx, ty, 10);
+	coord = multi_bonds (x, y, tx, ty, mb_dist);
 	Drawline (coord->x, coord->y, coord->tx, coord->ty, 0, 0);
 	Drawline (x, y, tx, ty, 0, 0);
-	coord = multi_bonds (tx, ty, x, y, 10);
+	coord = multi_bonds (tx, ty, x, y, mb_dist);
 	Drawline (coord->x, coord->y, coord->tx, coord->ty, 0, 0);
 	Drawline (x, y, tx, ty, 0, 0);
       }
       break;
     case 14:
       {				/*left partial double */
-	coord = multi_bonds (x, y, tx, ty, 10);
+	coord = multi_bonds (x, y, tx, ty, mb_dist);
 	DrawDashed (coord->x, coord->y, coord->tx, coord->ty, 0, 0);
 	Drawline (x, y, tx, ty, 0, 0);
       }
       break;
     case 15:
       {				/*right partial double */
-	coord = multi_bonds (tx, ty, x, y, 10);
+	coord = multi_bonds (tx, ty, x, y, mb_dist);
 	DrawDashed (coord->x, coord->y, coord->tx, coord->ty, 0, 0);
 	Drawline (x, y, tx, ty, 0, 0);
       }
@@ -1014,7 +1014,7 @@ Drawspline (int x0, int y0, int x1, int y1, int x2, int y2, int x3, int y3,
 
 
 void
-Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int serif_flag, int size, int preview)
+Drawstring (int x, int y, char *cc, int direct, int active, int thecolor, int serif_flag, int size, int preview)
 /* draws a label with sub- and superscripting, symbols and text justification */
 {
   int ha, tw, a;
@@ -1022,6 +1022,7 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
   int d, hx, n;
   int shiftall = 0;
   int variance[MAXCL];
+  gchar *c;
 #ifdef GTK2
   gchar *l="       ";
   gunichar hc, hl;
@@ -1032,7 +1033,7 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
   static PangoLayout *thelayout;
 #else
   char *l, *hc, hl[2];
-  char text[MAXCL];
+  unsigned char text[MAXCL];
   char symbol[MAXCL];
   char slanted[MAXCL];
   char bold[MAXCL];
@@ -1060,6 +1061,8 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
   y = y * size_factor;
   
 #ifdef GTK2
+  //  c=g_locale_to_utf8(cc,-1,NULL,NULL,NULL);
+  c=g_convert(cc,-1,"UTF-8","ISO8859-1",NULL,NULL,NULL);
   if (!thelayout) thelayout = gtk_widget_create_pango_layout(drawing_area,"X");
   pango_layout_set_font_description(thelayout,font[fontsize]);
   pango_layout_get_pixel_size(thelayout, &tw, &a);  
@@ -1069,6 +1072,7 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
   ha = ha/2;
   n = (int) g_utf8_strlen(c,-1);
 #else  
+  c=cc;
   a = gdk_char_height (font[fontsize], 'X');
   ha = gdk_char_height (font[fontsize], 'x') / 2;
   n = (int)strlen (c);
@@ -1104,8 +1108,10 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 		  --n;
 		  if (hc == '{')
 		    {
-		      shiftall = variance[d];
 		      --n;
+		      shiftall = variance[d];
+			c=g_utf8_next_char(c);		    
+			hc=g_utf8_get_char(c);
 		    }
 		}
 	      else
@@ -1411,6 +1417,7 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 
 /* erase a circular area slightly larger than the current character to
    create some space around the label */
+   if (text[d] != 183) {
     if (preview)
       gdk_draw_arc (picture, drawing_area->style->white_gc, 1,
 		    x - 5 * size_factor,
@@ -1421,6 +1428,7 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
 		    x - 5 * size_factor,
 		    y - a + ha - 5 * size_factor + variance[d],
 		    tw + 8 * size_factor, a + 10 * size_factor, 0, 360 * 64);
+    }
       x = x + tw;
     }
 
@@ -1435,8 +1443,99 @@ Drawstring (int x, int y, char *c, int direct, int active, int thecolor, int ser
   for (d = 0; d < n; d++)
     {
 #ifdef GTK2
-//      l = g_locale_to_utf8((gchar*)text[d],1,NULL,NULL,NULL);
+	memset(l,0,sizeof(l));
 	g_unichar_to_utf8((gunichar)text[d], l);
+	if (symbol[d]) {
+	unsigned int unicodechar=text[d]+848;
+	
+	switch (unicodechar){ /* catch sequence mismatches with X Symbol font*/
+			case 915: /*C*/
+			case 947: /*c*/
+				unicodechar+=20;
+				break;
+			case 918:
+			case 950: /*f*/
+				unicodechar+=16;
+				break;
+			case 919:	
+			case 951: /*g*/
+				unicodechar-=4;
+				break;
+			case 920:
+			case 952: /*h*/
+				unicodechar-=1;
+				break;
+			case 922: /*J is vartheta*/
+				unicodechar=977;
+				break;
+			case 954: /*j is varphi*/
+				unicodechar=981;
+				break;
+			case 923:
+			case 924:
+			case 925:
+			case 955:
+			case 956:
+			case 957:
+				unicodechar-=1;
+				break;
+			case 926: /*N*/
+				unicodechar=78;
+				break;
+			case 958: /*n*/
+				unicodechar=118;
+				break;
+			case 929: /*Q*/
+				unicodechar=920;
+				break;
+			case 961: /*p*/
+				unicodechar=952;
+				break;
+			case 962: 
+				unicodechar-=1;
+				break;
+			case 966:/*v*/
+				unicodechar=982;
+				break;
+			case 967: /*w*/
+				unicodechar=969;
+				break;
+			case 968:
+				unicodechar=958;
+				break;
+			case 969:
+				unicodechar-=1;
+				break;
+			case 970:
+				unicodechar=950;
+				break;						
+			case 930: /*R*/
+				unicodechar-=1;
+				break;
+			case 934: /*V*/
+				unicodechar=962;
+				break;
+			case 935: /*W*/
+				unicodechar+=2;
+				break;	
+			case 936: /*X*/
+				unicodechar=926;
+				break;
+			case 937: /*Y*/
+				unicodechar-=1;
+				break;
+			case 938:
+				unicodechar=90;
+				break;	
+			case 1031: /*centered dot*/									case 775: /* bullet */
+				unicodechar=8226;
+				break;	
+			default:
+				break;
+			}				 
+
+	g_unichar_to_utf8((gunichar)unicodechar,l);
+	}
 #else      
       hl[0] = text[d];
       hl[1] = 0;
@@ -1657,9 +1756,9 @@ Load_Font ()
 
 int i;
 
-  gchar *pangosymtype[]= {"Symbol 8", "Symbol 10", "Symbol 12", "Courier 14",
+  gchar *pangosymtype[]= {"Symbol 8", "Symbol 10", "Symbol 12", "Symbol 14",
                           "Symbol 18", "Symbol 20", "Symbol 24" };
-  gchar *pangossymtype[]= {"Symbol 8", "Symbol 8", "Symbol 10", "Courier 12",
+  gchar *pangossymtype[]= {"Symbol 8", "Symbol 8", "Symbol 10", "Symbol 12",
                           "Symbol 14", "Symbol 18", "Symbol 24" };
   gchar *pangofntype[]= { "Helvetica 8", "Helvetica 10", "Helvetica 12",
                           "Helvetica 14", "Helvetica 17", "Helvetica 20", 
